@@ -10,4 +10,4 @@ def get_screenshot(driver: object, settings: BrowserSettings, file_name: str | N
     else:
         destination_dir = helper.directory.ensure_trailing_slash(destination_dir)
         helper.directory.create_if_not_exists(destination_dir)
-    driver.save_screenshot(f"{destination_dir}{file_name}")
+    driver.save_screenshot(f"{destination_dir}{file_name}")  # type: ignore
