@@ -1,4 +1,5 @@
 from ... import helper
+from ...model.type.url import URL
 from ..get.url.current import get_current_url
 from .url import open_url
 
@@ -8,6 +9,7 @@ def open_url_if_not_current(driver: object,
                             ignore_trailing_slash: bool = True,
                             ignore_parameters: bool = False,
                             ignore_https: bool = False) -> None:
+    url = URL(url)
     current_url = get_current_url(driver)
     if ignore_https:
         current_url, url = helper.url.mediate_https(current_url, url)
