@@ -1,5 +1,6 @@
 from ... import helper
 from ...constant import timeout
+from ...model.type.xpath import XPath
 from ..get.text.from_element import get_text_from_element
 from .for_element import wait_for_element
 
@@ -8,5 +9,6 @@ def wait_until_text_changes(driver: object, xpath: str, baseline_text: str, time
     def has_text_changed(driver: object, baseline_text: str) -> bool:
         return get_text_from_element(driver, xpath) != baseline_text
 
+    xpath = XPath(xpath)
     wait_for_element(driver, xpath, timeout)
-    helper.retry.until_condition_is_true(has_text_changed(driver, baseline_text), timeout)
+    helper.retry.until_condition_is_true(driver, baseline_text, func=has_text_changed, timeout=timeout)
