@@ -1,5 +1,6 @@
 from ... import helper
 from ...constant import timeout
+from ...model.type.url import URL
 from ..get.url.current import get_current_url
 
 
@@ -7,4 +8,5 @@ def wait_until_url_changes(driver: object, baseline_url: str, timeout: int = tim
     def has_url_changed(driver: object, baseline_url: str) -> bool:
         return get_current_url(driver) != baseline_url
 
-    helper.retry.until_condition_is_true(has_url_changed(driver, baseline_url), timeout)
+    baseline_url = URL(baseline_url)
+    helper.retry.until_condition_is_true(driver, baseline_url, func=has_url_changed, timeout=timeout)
