@@ -1,7 +1,6 @@
 from ....model.browser.base.driver import BrowserDriver
 from ....model.browser.base.settings import BrowserSettings
 from ....model.driver_methods import DriverMethods
-from .current_handle import get_current_window_handle
 from .position import get_window_position
 from .size import get_window_size
 
@@ -10,11 +9,6 @@ class WindowGetDriverMethods(DriverMethods):
     def __init__(self, browser_driver: BrowserDriver, settings: BrowserSettings) -> None:
         super().__init__(browser_driver, settings)
 
-    def current_handle(self) -> str:
-        """Get the ID of the current window."""
-
-        return get_current_window_handle(self._driver)
-
     def position(self) -> tuple[int, int]:
         """Get the coordinates of the top left corner of the browser window on the screen. Usage:
 
