@@ -7,7 +7,7 @@ from ..model.browser.base.driver import BrowserDriver
 from ..model.browser.base.type import BrowserType
 
 
-def set_image_loading(browser_driver: BrowserDriver, load_images: bool = True):
+def set_image_loading(browser_driver: BrowserDriver, load_images: bool = True) -> None:
     if browser_driver.settings.type is BrowserType.INTERNET_EXPLORER and operating_system.is_windows():
         value = "yes" if load_images else "no"
         key = OpenKey(HKEY_CURRENT_USER, r"Software\Microsoft\Internet Explorer\Main", 0, KEY_ALL_ACCESS)
